@@ -5,7 +5,8 @@ import networkx as nx
 import matplotlib.pyplot as plt
 from collections import deque
 from typing import Any, Optional, List, Union
-from loguru import logger
+import logging
+logger = logging.getLogger(__name__)
 from networkx.exception import NetworkXException
 
 from selenium.common import WebDriverException
@@ -90,14 +91,20 @@ class PageNavigator:
         for i in range(len(path) - 1):
             current_page = path[i]
             next_page = path[i + 1]
-            next_class_name = next_page.__repr__
-            transition_method = current_page.edges[next_class_name]
+            transition_method = current_page.edges[next_page.__class__.__name__]
             self.logger.info(
-                f"Navigating from {current_page.__repr__} to {next_class_name} "
+                f"Navigating from {current_page.__repr__} to {next_page.__repr__} "
                 f"via method {transition_method.__repr__}"
             )
             transition_method()
 
+    def perform_navigation(self, path: List["PageBase"], timeout: int = 55) -> None:
+        for i in range(len(path) - 1):
+            current_page = path[i]
+            next_page = path[i + 1]
+            transition_method = current_page.edges[next_page.__class__.__name__]
+            transition_method()
+
     def save_graph(self, path: str = "page_graph.png"):
         self.graph_manager.save_graph_image(path)
 
