@@ -1,12 +1,9 @@
 import inspect
-import json
 import re
 from typing import Tuple, Dict, Union, Any, Optional
 
-# Удаляем импорт loguru
-# from loguru import logger
-# Используем наш логгер
-from shadowstep.utils import get_logger
+import logging
+logger = logging.getLogger(__name__)
 
 """
 Sorry, I'm too dumb to solve this module's problem correctly. So I did it primitively.
@@ -142,8 +139,7 @@ ui_selector_methods = {
 
 
 class LocatorConverter:
-    # Получаем логгер для класса
-    logger = get_logger("shadowstep.utils.locator_converter.LocatorConverter")
+    logger = logger
 
     DICT_TO_XPATH: Dict[str, str] = {
         "checkable": "checkable",
